@@ -55,6 +55,7 @@
 static gboolean applet_factory (PanelApplet *applet, const gchar *iid, gpointer data);
 static gboolean applet_fill (PanelApplet *applet);
 static void cdplayer_load_config(CDPlayerData *cd);
+static void show_error(CDPlayerData *cd);
 static void cdplayer_save_config(CDPlayerData *cd);
 
 static void cdplayer_destroy(GtkWidget * widget, gpointer data);
@@ -88,7 +89,7 @@ static void ref_and_remove(GtkWidget *w);
 static GtkWidget *pack_make_hbox(CDPlayerData* cd);
 static void pack_thing(GtkWidget *box, GtkWidget *w, gboolean expand);
 
-static gboolean cd_try_open(CDPlayerData *cd);
+static gboolean cd_try_open(CDPlayerData *cd, int *errcode);
 static void cd_close (CDPlayerData *cd);
 
 static void cd_panel_update(GtkWidget * cdplayer, CDPlayerData * cd);
@@ -145,15 +146,15 @@ applet_fill (PanelApplet *applet)
     int err;
 
     gnome_window_icon_set_default_from_file (GNOME_ICONDIR"/gnome-cdplayer-icon.png");
-    
+    panel_applet_set_flags (applet, PANEL_APPLET_EXPAND_MINOR);
     cdplayer_init_stock_icons ();
       
     cd = g_new0(CDPlayerData, 1);
     cd->panel.applet = GTK_WIDGET (applet);
     
     /* the rest of the widgets go in here */
-    cdplayer = cd->panel.frame = gtk_frame_new(NULL);
-    gtk_frame_set_shadow_type(GTK_FRAME(cdplayer), GTK_SHADOW_IN);
+    cdplayer = cd->panel.frame = gtk_hbox_new(FALSE, 0);
+   
     g_object_set_data (G_OBJECT(cdplayer), "cd-info", cd);
     g_signal_connect_after (G_OBJECT (cdplayer), "realize", G_CALLBACK (cdplayer_realize), cd);
     gtk_widget_show(cdplayer);
@@ -186,7 +187,10 @@ applet_fill (PanelApplet *applet)
     led_create_widgets(&cd->panel.time, &cd->panel.track_control.display, (gpointer)cd);
 
     gtk_container_add (GTK_CONTAINER (applet), cdplayer);
-    gtk_tooltips_set_tip (tooltips, cd->panel.applet, _("CD Player"), NULL);
+    /* FIXME: setting the tooltip on the applet doesn't allow for the buttons to expand all
+    ** the way and thus we lose on Fitt's law. However with no tooltip, focus indication can't
+    ** be drawn around the applet */
+    /*gtk_tooltips_set_tip (tooltips, cd->panel.applet, _("CD Player"), NULL);*/
     make_applet_accessible (cd); 
 
     /* panel_applet_add_preferences (applet, "/schemas/apps/cdplayer-applet/prefs", NULL); */
@@ -215,6 +219,31 @@ applet_fill (PanelApplet *applet)
     return(TRUE);
 }
 
+static void
+show_error (CDPlayerData *cd)
+{
+    static GtkWidget *dialog = NULL;
+    if (dialog) {
+        gtk_window_present (GTK_WINDOW (dialog));
+        return;
+    }
+    dialog = gtk_message_dialog_new (NULL,
+				     GTK_DIALOG_DESTROY_WITH_PARENT,
+				     GTK_MESSAGE_ERROR,
+				     GTK_BUTTONS_OK,
+				     _("You do not have permission to use the CD player."));
+
+    g_signal_connect (dialog, "response",
+		      G_CALLBACK (gtk_widget_destroy),
+		      NULL);
+    g_signal_connect (G_OBJECT(dialog), "destroy",
+                      G_CALLBACK(gtk_widget_destroyed), &dialog);
+    gtk_window_set_resizable (GTK_WINDOW (dialog), FALSE);
+    gtk_window_set_screen (GTK_WINDOW (dialog),
+			   gtk_widget_get_screen (cd->panel.applet));
+    gtk_widget_show (dialog);
+}
+
 static void
 cdplayer_load_config(CDPlayerData *cd)
 {
@@ -238,12 +267,13 @@ cdplayer_destroy(GtkWidget * widget, gpointer data)
 {
     CDPlayerData *cd = data;
     GtkTooltips *tooltips;
+    int err;
 
     if (cd->timeout != 0)
         gtk_timeout_remove(cd->timeout);
     cd->timeout = 0;
     /* Since the applet is being destroyed, stop playing cd */
-    if(cd_try_open(cd))
+    if(cd_try_open(cd, &err))
         cdrom_stop(cd->cdrom_device);
     cd_close (cd);
 
@@ -303,8 +333,8 @@ start_gtcd_cb (BonoboUIComponent *component,
 	dialog = gtk_message_dialog_new (NULL,
 					 GTK_DIALOG_DESTROY_WITH_PARENT,
 					 GTK_MESSAGE_ERROR,
-					 GTK_BUTTONS_CLOSE,
-					 _("There was an error executing '%s' : %s"),
+					 GTK_BUTTONS_OK,
+					 _("There was an error executing '%s': %s"),
 					 "gnome-cd",
 					 error->message);
 
@@ -340,20 +370,22 @@ activate_cb (GtkEntry     *entry,
 	     CDPlayerData *cd)
 {
     gchar *newpath;
+    int err;
     
     newpath = gtk_editable_get_chars (GTK_EDITABLE (entry), 0, -1);
     if(newpath && strlen(newpath) > 2 && strcmp(cd->devpath, newpath))
             {
-		if(cd_try_open(cd))
+		if(cd_try_open(cd, &err))
 		    cdrom_stop(cd->cdrom_device);
                 cd_close(cd);
                 cd->devpath = g_strdup(newpath);
-                if (!cd_try_open(cd)) {
+                if (!cd_try_open(cd, &err)) {
                     GtkWidget *dialog;
+
                     dialog = gtk_message_dialog_new (NULL, GTK_DIALOG_DESTROY_WITH_PARENT,
                                   		     GTK_MESSAGE_ERROR,
-                                  		     GTK_BUTTONS_CLOSE,
-                                  		     "%s is not a proper device path",
+                                  		     GTK_BUTTONS_OK,
+                                  		     _("%s does not seem to be a CD player"),
                                   		     cd->devpath, NULL);
 
 		    gtk_window_set_screen (GTK_WINDOW (dialog),
@@ -386,6 +418,7 @@ static void
 set_default_device (GtkButton *button, gpointer data)
 {
     CDPlayerData *cd = data;
+    int err;
     GtkWidget *entry = g_object_get_data (G_OBJECT (button), "entry");
     
     if (!strcmp(cd->devpath, DEV_PATH))
@@ -395,7 +428,7 @@ set_default_device (GtkButton *button, gpointer data)
     if (cd->devpath)
         g_free(cd->devpath);
     cd->devpath = g_strdup(DEV_PATH);
-    cd_try_open(cd);
+    cd_try_open(cd, &err);
     gtk_entry_set_text (GTK_ENTRY (entry), cd->devpath);
     cdplayer_save_config(cd);  
 }
@@ -430,14 +463,15 @@ preferences_cb (BonoboUIComponent *component,
     gtk_dialog_set_default_response(GTK_DIALOG (dialog), GTK_RESPONSE_CLOSE);
     gtk_window_set_resizable (GTK_WINDOW (dialog), FALSE);
     gtk_dialog_set_has_separator (GTK_DIALOG (dialog), FALSE);
+    gtk_container_set_border_width (GTK_CONTAINER (dialog), 5);
     box = GTK_DIALOG(dialog)->vbox;
     
     hbox = gtk_hbox_new (FALSE, 12);
-    gtk_container_set_border_width (GTK_CONTAINER (hbox), 12);
+    gtk_container_set_border_width (GTK_CONTAINER (hbox), 5);
     gtk_box_pack_start(GTK_BOX(box), hbox, TRUE, TRUE, 0);
     gtk_widget_show(hbox);
 
-    label = gtk_label_new_with_mnemonic(_("Device _Path:"));
+    label = gtk_label_new_with_mnemonic(_("Device _path:"));
     gtk_box_pack_start(GTK_BOX(hbox), label, FALSE, FALSE, 0);
     gtk_widget_show(label);
 
@@ -585,21 +619,29 @@ ui_component_event (BonoboUIComponent *comp,
 static void
 setup_box(CDPlayerData* cd)
 {
-    GtkWidget *hbox, *vbox;
+    GtkWidget *hbox, *vbox, *vbox2;
+    GtkWidget *time_frame, *track_frame;
 
     if(cd->panel.box)
         destroy_box(cd);
+        
+    time_frame = gtk_frame_new (NULL);
+    g_object_ref (time_frame);
+    track_frame = gtk_frame_new (NULL);
+    g_object_ref (track_frame);
 
     if ((cd->orient == PANEL_APPLET_ORIENT_DOWN || cd->orient == PANEL_APPLET_ORIENT_UP) && cd->size < 48  )
     {
         /* tiny horizontal panel */
         cd->panel.box = gtk_hbox_new(FALSE, 0);
-        gtk_container_add(GTK_CONTAINER(cd->panel.frame), cd->panel.box);
+        gtk_box_pack_start(GTK_BOX(cd->panel.frame), cd->panel.box, TRUE, TRUE, 0);
         pack_thing(cd->panel.box, cd->panel.track_control.prev, FALSE);
-        pack_thing(cd->panel.box, cd->panel.track_control.display, TRUE);
+        gtk_container_add (GTK_CONTAINER (track_frame), cd->panel.track_control.display);
+        pack_thing(cd->panel.box,track_frame, TRUE);
         pack_thing(cd->panel.box, cd->panel.track_control.next, FALSE);
-        pack_thing(cd->panel.box, cd->panel.time, TRUE);
-        pack_thing(cd->panel.box, cd->panel.play_control.play_pause, FALSE);
+        gtk_container_add (GTK_CONTAINER (time_frame), cd->panel.time);
+        pack_thing(cd->panel.box, time_frame, TRUE);
+        pack_thing(cd->panel.box, cd->panel.play_control.play_pause, TRUE);
         pack_thing(cd->panel.box, cd->panel.play_control.stop, FALSE);
         pack_thing(cd->panel.box, cd->panel.play_control.eject, FALSE);
         gtk_widget_show(cd->panel.box);
@@ -611,8 +653,11 @@ setup_box(CDPlayerData* cd)
         cd->panel.box = gtk_vbox_new(FALSE, 0);
         gtk_container_add(GTK_CONTAINER(cd->panel.frame), cd->panel.box);
         hbox = pack_make_hbox(cd);
-        pack_thing(hbox, cd->panel.time, TRUE);
-        pack_thing(hbox, cd->panel.track_control.display, TRUE);
+        vbox = gtk_vbox_new (FALSE, 0);
+        gtk_container_add (GTK_CONTAINER (time_frame), vbox);
+        gtk_box_pack_start  (GTK_BOX (vbox), cd->panel.time, TRUE, TRUE, 0);
+        gtk_box_pack_start  (GTK_BOX (vbox), cd->panel.track_control.display, TRUE, TRUE, 0);
+        pack_thing(cd->panel.box, time_frame, TRUE);        
         hbox = pack_make_hbox(cd);
         pack_thing(hbox, cd->panel.play_control.play_pause, FALSE);
         pack_thing(hbox, cd->panel.play_control.stop, FALSE);
@@ -621,13 +666,16 @@ setup_box(CDPlayerData* cd)
         pack_thing(hbox, cd->panel.track_control.next, FALSE);
         gtk_widget_show(cd->panel.box);
     }
-    else if ((cd->orient == PANEL_APPLET_ORIENT_LEFT || cd->orient == PANEL_APPLET_ORIENT_RIGHT) && cd->size < 128  )
+    else if ((cd->orient == PANEL_APPLET_ORIENT_LEFT || cd->orient == PANEL_APPLET_ORIENT_RIGHT) && cd->size < 48  )
     {
         cd->panel.box = gtk_vbox_new(FALSE, 0);
 	vbox = cd->panel.box;
         gtk_container_add(GTK_CONTAINER(cd->panel.frame), cd->panel.box);
-        pack_thing(cd->panel.box, cd->panel.time, TRUE);
-        pack_thing(vbox, cd->panel.track_control.display, TRUE);
+        vbox2 = gtk_vbox_new (FALSE, 0);
+        gtk_container_add (GTK_CONTAINER (time_frame), vbox2);
+        gtk_box_pack_start  (GTK_BOX (vbox2), cd->panel.time, TRUE, TRUE, 0);
+        gtk_box_pack_start  (GTK_BOX (vbox2), cd->panel.track_control.display, TRUE, TRUE, 0);
+        pack_thing(cd->panel.box, time_frame, TRUE);
         pack_thing(vbox, cd->panel.play_control.play_pause, TRUE);
         pack_thing(vbox, cd->panel.track_control.prev, TRUE);
         pack_thing(vbox, cd->panel.track_control.next, TRUE);
@@ -640,16 +688,20 @@ setup_box(CDPlayerData* cd)
         /* other panel sizes/orientations should go here */
         cd->panel.box = gtk_vbox_new(FALSE, 0);
         gtk_container_add(GTK_CONTAINER(cd->panel.frame), cd->panel.box);
-        pack_thing(cd->panel.box, cd->panel.time, TRUE);
+        vbox2 = gtk_vbox_new (FALSE, 0);
+        gtk_container_add (GTK_CONTAINER (time_frame), vbox2);
+        gtk_box_pack_start  (GTK_BOX (vbox2), cd->panel.time, TRUE, TRUE, 0);
+        gtk_box_pack_start  (GTK_BOX (vbox2), cd->panel.track_control.display, TRUE, TRUE, 0);
+        pack_thing(cd->panel.box, time_frame, TRUE);
         hbox = pack_make_hbox(cd);
-        pack_thing(hbox, cd->panel.play_control.play_pause, FALSE);
-        pack_thing(hbox, cd->panel.play_control.stop, FALSE);
-        pack_thing(hbox, cd->panel.play_control.eject, FALSE);
+        pack_thing(hbox, cd->panel.play_control.play_pause, TRUE);
+        pack_thing(hbox, cd->panel.play_control.stop, TRUE);
         hbox = pack_make_hbox(cd);
-        pack_thing(hbox, cd->panel.track_control.prev, FALSE);
-        pack_thing(hbox, cd->panel.track_control.display, TRUE);
-        pack_thing(hbox, cd->panel.track_control.next, FALSE);
-        gtk_widget_show(cd->panel.box);
+        pack_thing(hbox, cd->panel.track_control.prev, TRUE);
+        pack_thing(hbox, cd->panel.track_control.next, TRUE);
+        hbox = pack_make_hbox(cd);
+        pack_thing(hbox, cd->panel.play_control.eject, TRUE);
+       gtk_widget_show(cd->panel.box);
     }
     gtk_widget_show_all(cd->panel.frame);
 }
@@ -717,11 +769,10 @@ pack_thing(GtkWidget *box, GtkWidget *w, gboolean expand)
 
 /* Deal with the hardware stuff */
 static gboolean
-cd_try_open(CDPlayerData *cd)
+cd_try_open(CDPlayerData *cd, int *err)
 {
-    int err;
     if(cd->cdrom_device == NULL) {
-        cd->cdrom_device = cdrom_open(cd->devpath, &err);
+        cd->cdrom_device = cdrom_open(cd->devpath, err);
         return cd->cdrom_device != NULL;
     }
     return TRUE;
@@ -741,8 +792,9 @@ cd_panel_update(GtkWidget * cdplayer, CDPlayerData * cd)
 {
     cdrom_device_status_t stat;
     gboolean description = FALSE;
+    int err;
 
-    if (cd_try_open(cd)) {
+    if (cd_try_open(cd, &err)) {
         if (cdrom_get_status(cd->cdrom_device, &stat) == DISC_NO_ERROR)
         {
             switch (stat.audio_status)
@@ -817,9 +869,13 @@ cdplayer_play_pause(GtkWidget * w, gpointer data)
     cdrom_device_status_t stat;
     int status;
     int ret;
+    int err;
 
-    if(!cd_try_open(cd))
+    if(!cd_try_open(cd, &err)) {
+        if (err == EACCES) 
+            show_error (cd);
         return;
+    }
 
     status = cdrom_get_status(cd->cdrom_device, &stat);
     if (status == DISC_NO_ERROR) {
@@ -853,7 +909,7 @@ cdplayer_play_pause(GtkWidget * w, gpointer data)
 		dialog = gtk_message_dialog_new (NULL,
 						 GTK_DIALOG_DESTROY_WITH_PARENT,
 						 GTK_MESSAGE_ERROR,
-						 GTK_BUTTONS_CLOSE,
+						 GTK_BUTTONS_OK,
 						 _("Audio device is busy, or being used by another application"),
 						 NULL);
 		gtk_window_set_screen (GTK_WINDOW (dialog),
@@ -870,8 +926,13 @@ static void
 cdplayer_stop(GtkWidget * w, gpointer data)
 {
     CDPlayerData *cd = data;
-    if(!cd_try_open(cd))
+    int err;
+    
+    if(!cd_try_open(cd, &err)) {
+        if (err == EACCES) 
+            show_error (cd);
         return;
+    }
     cdrom_stop(cd->cdrom_device);
 
 }
@@ -880,8 +941,12 @@ static void
 cdplayer_prev(GtkWidget * w, gpointer data)
 {
     CDPlayerData *cd = data;
-    if(!cd_try_open(cd))
+    int err;
+    if(!cd_try_open(cd, &err)) {
+        if (err == EACCES)
+            show_error (cd);
         return;
+    }
     cdrom_prev(cd->cdrom_device);
 
 }
@@ -890,8 +955,12 @@ static void
 cdplayer_next(GtkWidget * w, gpointer data)
 {
     CDPlayerData *cd = data;
-    if(!cd_try_open(cd))
+    int err;
+    if(!cd_try_open(cd, &err)) {
+        if (err == EACCES)
+            show_error (cd);
         return;
+    }
     cdrom_next(cd->cdrom_device);
 
 }
@@ -901,8 +970,12 @@ cdplayer_eject(GtkWidget * w, gpointer data)
 {
     cdrom_device_status_t stat;
     CDPlayerData *cd = data;
-    if(!cd_try_open(cd))
+    int err;
+    if(!cd_try_open(cd, &err)) {
+        if (err == EACCES)
+            show_error (cd);
         return;
+     }
     if(cdrom_get_status(cd->cdrom_device, &stat) == DISC_TRAY_OPEN)
         /*
           FIXME: if there is no disc, we get TRAY_OPEN even
