@@ -38,10 +38,12 @@ void start_callback_update();
 
 void build_table              (charpick_data     *curr_data);
 void add_to_popup_menu (charpick_data *curr_data);
+void populate_menu (charpick_data *curr_data);
 void save_chartable (charpick_data *curr_data);
 void show_preferences_dialog  (BonoboUIComponent *uic,
 			       charpick_data     *curr_data,
 			       const char        *verbname);
+gchar *run_edit_dialog  (gchar *string, gchar *title);
 void set_atk_name_description (GtkWidget         *widget,
 			       const char        *name,
 			       const char        *description);
