@@ -49,8 +49,10 @@
 	typedef struct {
 		char *price;
 		int pricelen;
+		int priceheight;
 		char *change;
 		int changelen;
+		int changeheight;
 		int color;
 	} StockQuote;
 	
@@ -67,6 +69,7 @@
 		gchar *fgcolor;
 		gchar *font;
 		gboolean buttons;
+		gboolean use_default_theme;
 		gint width;
 
 	} gtik_properties;
@@ -166,26 +169,35 @@
 	{
 		GArray *quotes = stockdata->quotes;
 		PangoRectangle rect;
+		PangoContext *context;
 		int i;
 		
 		if (stockdata->my_font)
 			pango_font_description_free (stockdata->my_font);
-		stockdata->my_font = pango_font_description_from_string (stockdata->props.font);	
-		
-		if (!stockdata->my_font) {
-			stockdata->my_font = pango_font_description_from_string ("fixed 12");
+		stockdata->my_font = NULL;
+		if (stockdata->props.font ) {
+			stockdata->my_font = pango_font_description_from_string (stockdata->props.font);
+		}
+	
+		if (stockdata->props.use_default_theme || !stockdata->my_font) {
+			context = gtk_widget_get_pango_context (stockdata->applet);
+			stockdata->my_font = pango_font_description_copy (
+								pango_context_get_font_description (context));
 		}
 		pango_layout_set_font_description (stockdata->layout, stockdata->my_font);
+
 		/* make sure the cached strings widths are updated */
 		for (i=0; i< stockdata->setCounter; i++) {
 			pango_layout_set_text (stockdata->layout, 
 					       STOCK_QUOTE(quotes->data)[i].price, -1);
 			pango_layout_get_pixel_extents (stockdata->layout, NULL, &rect);
 			STOCK_QUOTE(quotes->data)[i].pricelen = rect.width;
+			STOCK_QUOTE(quotes->data)[i].priceheight = rect.height;
 			pango_layout_set_text (stockdata->layout, 
 					       STOCK_QUOTE(quotes->data)[i].change, -1);
 			pango_layout_get_pixel_extents (stockdata->layout, NULL, &rect);
 			STOCK_QUOTE(quotes->data)[i].changelen = rect.width;
+			STOCK_QUOTE(quotes->data)[i].changeheight = rect.height;
 		}
 	}
 
@@ -311,11 +323,13 @@ static gint updateOutput(gpointer data)
 									 NULL);
 		if (!stockdata->props.ucolor)
 			stockdata->props.ucolor = g_strdup ("#00ff00");
+			
+		stockdata->props.use_default_theme = panel_applet_gconf_get_bool(applet,
+									  "use_default_theme",
+									  NULL);
 		stockdata->props.font = panel_applet_gconf_get_string (applet,
 								       "font",
 								       NULL);
-		if (!stockdata->props.font)
-			stockdata->props.font = g_strdup ("fixed 12");
 				
 		stockdata->props.buttons = panel_applet_gconf_get_bool(applet,
 									  "buttons",
@@ -565,7 +579,7 @@ static gint updateOutput(gpointer data)
 		PangoRectangle logical_rect;
 		int	comp;
 		gint n = 0, totalLen2 = 0;
-		int start, end, width;
+		int start, end, width, max_height=0, y;
 
 		/* FOR COLOR */
 		int totalLoc;
@@ -574,8 +588,12 @@ static gint updateOutput(gpointer data)
 
 		totalLoc = 0;
 		totalLen = 0;
-	
-		gdk_gc_set_foreground( gc, &stockdata->gdkBGcolor );
+
+		if (stockdata->props.use_default_theme)
+			gdk_gc_set_foreground( gc, &stockdata->applet->style->base[GTK_WIDGET_STATE (stockdata->applet)] );
+		else
+			gdk_gc_set_foreground( gc, &stockdata->gdkBGcolor );
+		
 		gdk_draw_rectangle (stockdata->pixmap,
 				    gc, TRUE, 0,0,
 				    drawing_area->allocation.width,
@@ -585,17 +603,19 @@ static gint updateOutput(gpointer data)
 		
 		for (i=0; i< stockdata->setCounter; i++) {
 			totalLen += STOCK_QUOTE(quotes->data)[i].pricelen + 10;
-			
+			max_height = MAX (max_height, STOCK_QUOTE(quotes->data)[i].priceheight);
 			if (stockdata->props.output == FALSE) {
 				if (*(STOCK_QUOTE(quotes->data)[i].change)) {
 					totalLen += STOCK_QUOTE(quotes->data)[i].changelen 
 						+ 10;
+					max_height = MAX (max_height, STOCK_QUOTE(quotes->data)[i].changeheight);
 					
 				}
 			}
 			
 		}
 		
+		y = MAX((drawing_area->allocation.height - max_height)/2, 0);
 		comp = 0 - totalLen;
 
 		if (stockdata->MOVE == 1) { stockdata->MOVE = 0; } 
@@ -628,16 +648,21 @@ static gint updateOutput(gpointer data)
 		}
 
 		for (i=0;i<stockdata->setCounter;i++) {
-
+			
+			
 			/* COLOR */
-			if (STOCK_QUOTE(quotes->data)[i].color == GREEN) {
-				gdk_gc_set_foreground( gc, &stockdata->gdkUcolor );
-			}
-			else if (STOCK_QUOTE(quotes->data)[i].color == RED) {
-				gdk_gc_set_foreground( gc, &stockdata->gdkDcolor );
-			}
+			if (stockdata->props.use_default_theme)
+				gdk_gc_set_foreground( gc, &stockdata->applet->style->fg[GTK_WIDGET_STATE (stockdata->applet)] );
 			else {
-				gdk_gc_set_foreground( gc, &stockdata->gdkFGcolor );
+				if (STOCK_QUOTE(quotes->data)[i].color == GREEN) {
+					gdk_gc_set_foreground( gc, &stockdata->gdkUcolor );
+				}
+				else if (STOCK_QUOTE(quotes->data)[i].color == RED) {
+					gdk_gc_set_foreground( gc, &stockdata->gdkDcolor );
+				}
+				else {
+					gdk_gc_set_foreground( gc, &stockdata->gdkFGcolor );
+				}
 			}
 
 			start = stockdata->location + totalLoc;
@@ -649,7 +674,7 @@ static gint updateOutput(gpointer data)
 					       STOCK_QUOTE(quotes->data)[i].price,
 					       -1);	
 				gdk_draw_layout (stockdata->pixmap, gc,
-					 start , 0,
+					 start , y,
 					 layout);
 			}
 			totalLoc += STOCK_QUOTE(quotes->data)[i].pricelen + 10;
@@ -663,7 +688,7 @@ static gint updateOutput(gpointer data)
 						STOCK_QUOTE(quotes->data)[i].change, -1);
 					gdk_draw_layout (stockdata->pixmap,
 					     		gc, stockdata->location + totalLoc,
-					     		0, layout);
+					     		y, layout);
 				}
 				totalLoc += STOCK_QUOTE(quotes->data)[i].changelen + 10;
 			}
@@ -915,6 +940,31 @@ static gint updateOutput(gpointer data)
 					     
 	}	
 	
+	static void
+	def_font_toggled (GtkToggleButton *button, gpointer data)
+	{
+		StockData *stockdata = data;
+		PanelApplet *applet = PANEL_APPLET (stockdata->applet);
+		GtkWidget *fonts_widget, *colors_widget;
+		gboolean toggle;
+		
+		toggle = gtk_toggle_button_get_active (button);
+		if (toggle != stockdata->props.use_default_theme)
+			stockdata->props.use_default_theme = toggle;
+		else
+			return;
+		panel_applet_gconf_set_bool (applet,"use_default_theme",
+					     stockdata->props.use_default_theme, NULL);
+					     
+		fonts_widget = g_object_get_data (G_OBJECT (button), "fonts_hbox");
+		colors_widget = g_object_get_data (G_OBJECT (button), "colors_hbox");
+		gtk_widget_set_sensitive (GTK_WIDGET (fonts_widget), 
+					             !stockdata->props.use_default_theme);
+		gtk_widget_set_sensitive (GTK_WIDGET (colors_widget), 
+					             !stockdata->props.use_default_theme);
+		load_fonts(stockdata);
+	}
+	
 	static void
 	add_symbol (GtkEntry *entry, gpointer data)
 	{
@@ -1295,13 +1345,13 @@ static gint updateOutput(gpointer data)
 		StockData * stockdata = data;
 		GtkWidget * notebook;
 		GtkWidget * vbox, *behav_vbox, *appear_vbox;
-		GtkWidget * vbox2;
-		GtkWidget *hbox, *hbox2, *hbox3;
+		GtkWidget * vbox2, *color_vbox;
+		GtkWidget *hbox, *hbox2, *hbox3, *font_hbox;
 		GtkWidget * label, *spin, *check;
 		GtkWidget *color;
 		GtkWidget *font;
 		GtkWidget *option, *menu, *menuitem;
-		GtkSizeGroup *size;
+		GtkSizeGroup *size, *size2;
 
 		int ur,ug,ub, dr,dg,db; 
 				
@@ -1326,14 +1376,17 @@ static gint updateOutput(gpointer data)
 		                                 GTK_RESPONSE_CLOSE);
 		gtk_dialog_set_has_separator (GTK_DIALOG (stockdata->pb), FALSE);
 		gtk_container_set_border_width (GTK_CONTAINER (stockdata->pb), 5);
+		gtk_widget_show (GTK_DIALOG (stockdata->pb)->vbox);
 		notebook = gtk_notebook_new ();
 		gtk_box_pack_start (GTK_BOX (GTK_DIALOG (stockdata->pb)->vbox), notebook,
 				    TRUE, TRUE, 0);
+		gtk_widget_show (notebook);
 
 		hbox = symbolManager(stockdata);
 		label = gtk_label_new (_("Symbols"));
 		gtk_notebook_append_page (GTK_NOTEBOOK (notebook), hbox, label);
 		gtk_container_set_border_width (GTK_CONTAINER (notebook), 5);
+		gtk_widget_show_all (hbox);
 		
 		behav_vbox = gtk_vbox_new (FALSE, 18);
 		gtk_container_set_border_width (GTK_CONTAINER (behav_vbox), 12);
@@ -1404,14 +1457,19 @@ static gint updateOutput(gpointer data)
 		gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(check),
 							   !stockdata->props.scroll);
 							   
+		gtk_widget_show_all (behav_vbox);
+							   
 		appear_vbox = gtk_vbox_new (FALSE, 18);
 		gtk_container_set_border_width (GTK_CONTAINER (appear_vbox), 12);
 		label = gtk_label_new (_("Appearance"));
 		gtk_notebook_append_page (GTK_NOTEBOOK (notebook), appear_vbox, label);
+		gtk_widget_show_all(appear_vbox);
+		gtk_widget_show_all (notebook);
 		
 		size = gtk_size_group_new (GTK_SIZE_GROUP_HORIZONTAL);
 		
 		vbox = create_hig_catagory (appear_vbox, _("Display"));
+		gtk_widget_show_all (vbox);
 		
 		hbox2 = gtk_hbox_new (FALSE, 6);
 		gtk_box_pack_start (GTK_BOX (vbox), hbox2, FALSE, FALSE, 0);
@@ -1421,6 +1479,7 @@ static gint updateOutput(gpointer data)
 				           G_CALLBACK (output_toggled), stockdata);
 		gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (check),
 							   stockdata->props.output);
+		gtk_widget_show_all (hbox2);
 
 		hbox2 = gtk_hbox_new (FALSE, 12);
 		gtk_box_pack_start (GTK_BOX (vbox), hbox2, FALSE, FALSE, 0);
@@ -1428,6 +1487,7 @@ static gint updateOutput(gpointer data)
 		gtk_misc_set_alignment (GTK_MISC (label), 0.0, 0.5);
 		gtk_box_pack_start (GTK_BOX (hbox2), label, FALSE, FALSE, 0);
 		gtk_size_group_add_widget (size, label);
+		gtk_widget_show_all (hbox2);
 		
 		hbox3 = gtk_hbox_new (FALSE, 6);
 		gtk_box_pack_start (GTK_BOX (hbox2), hbox3, FALSE, FALSE, 0);
@@ -1439,8 +1499,27 @@ static gint updateOutput(gpointer data)
 		gtk_box_pack_start (GTK_BOX (hbox3), spin, FALSE, FALSE, 0);
 		label = gtk_label_new (_("pixels"));
 		gtk_box_pack_start (GTK_BOX (hbox3), label, FALSE, FALSE, 0);
-							   
+		gtk_widget_show_all (hbox2);	
+		
+		 g_object_unref (size);
+		
+		vbox = create_hig_catagory (appear_vbox, _("Font and Colors"));
+		size = gtk_size_group_new (GTK_SIZE_GROUP_HORIZONTAL);
+		size2= gtk_size_group_new (GTK_SIZE_GROUP_HORIZONTAL);
+				
+		hbox2 = gtk_hbox_new (FALSE, 6);
+		gtk_box_pack_start (GTK_BOX (vbox), hbox2, FALSE, FALSE, 0);
+		check = gtk_check_button_new_with_mnemonic (_("Use _default theme font and colors"));
+		gtk_box_pack_start (GTK_BOX (hbox2), check, FALSE, FALSE, 0);
+		g_signal_connect (G_OBJECT (check), "toggled",
+				           G_CALLBACK (def_font_toggled), stockdata);
+		gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (check),
+							   stockdata->props.use_default_theme);
+		gtk_widget_show_all (hbox2);
+					   
 		hbox2 = gtk_hbox_new (FALSE, 12);
+		font_hbox = hbox2;
+		g_object_set_data (G_OBJECT (check), "fonts_hbox", hbox2);
 		gtk_box_pack_start (GTK_BOX (vbox), hbox2, FALSE, FALSE, 0);
 		label = gtk_label_new_with_mnemonic (_("_Font:"));
 		gtk_misc_set_alignment (GTK_MISC (label), 0.0, 0.5);
@@ -1448,19 +1527,21 @@ static gint updateOutput(gpointer data)
 		gtk_size_group_add_widget (size, label);
 		font = gnome_font_picker_new ();
 		gtk_label_set_mnemonic_widget (GTK_LABEL (label), font);
-		gnome_font_picker_set_font_name (GNOME_FONT_PICKER (font),
+		if (stockdata->props.font)
+			gnome_font_picker_set_font_name (GNOME_FONT_PICKER (font),
 						 stockdata->props.font);
 		gtk_box_pack_start (GTK_BOX (hbox2), font, FALSE, FALSE, 0);
 		g_signal_connect (G_OBJECT (font), "font_set",
                 		  G_CALLBACK (font_cb), stockdata);
-                		  
-                g_object_unref (size);
-		
-		vbox = create_hig_catagory (appear_vbox, _("Colors"));
-		size = gtk_size_group_new (GTK_SIZE_GROUP_HORIZONTAL);
-					   
+                gtk_size_group_add_widget (size2, font);
+		gtk_widget_show_all (hbox2);				  
+               	
+		color_vbox = gtk_vbox_new (FALSE, 6);
+		g_object_set_data (G_OBJECT (check), "colors_hbox", color_vbox);
+		gtk_box_pack_start (GTK_BOX (vbox), color_vbox, TRUE, TRUE, 0);
+				   
 		hbox2 = gtk_hbox_new (FALSE, 12);
-		gtk_box_pack_start (GTK_BOX (vbox), hbox2, FALSE, FALSE, 0);
+		gtk_box_pack_start (GTK_BOX (color_vbox), hbox2, FALSE, FALSE, 0);
 		label = gtk_label_new_with_mnemonic (_("Stock _raised:"));
 		gtk_misc_set_alignment (GTK_MISC (label), 0.0, 0.5);
 		gtk_box_pack_start (GTK_BOX (hbox2), label, FALSE, FALSE, 0);
@@ -1471,11 +1552,12 @@ static gint updateOutput(gpointer data)
 		gnome_color_picker_set_i8(GNOME_COLOR_PICKER (color), 
 					  ur, ug, ub, 255);
 		gtk_box_pack_start (GTK_BOX (hbox2), color, FALSE, FALSE, 0);
+		gtk_size_group_add_widget (size2, color);
 		g_signal_connect(G_OBJECT(color), "color_set",
 				G_CALLBACK(ucolor_set_cb), stockdata);
 				
 		hbox2 = gtk_hbox_new (FALSE, 12);
-		gtk_box_pack_start (GTK_BOX (vbox), hbox2, FALSE, FALSE, 0);
+		gtk_box_pack_start (GTK_BOX (color_vbox), hbox2, FALSE, FALSE, 0);
 		label = gtk_label_new_with_mnemonic (_("Stock _lowered:"));
 		gtk_misc_set_alignment (GTK_MISC (label), 0.0, 0.5);
 		gtk_box_pack_start (GTK_BOX (hbox2), label, FALSE, FALSE, 0);
@@ -1486,11 +1568,12 @@ static gint updateOutput(gpointer data)
 		gnome_color_picker_set_i8(GNOME_COLOR_PICKER (color), 
 					  ur, ug, ub, 255);
 		gtk_box_pack_start (GTK_BOX (hbox2), color, FALSE, FALSE, 0);
+		gtk_size_group_add_widget (size2, color);
 		g_signal_connect(G_OBJECT(color), "color_set",
 				G_CALLBACK(dcolor_set_cb), stockdata);
 				
 		hbox2 = gtk_hbox_new (FALSE, 12);
-		gtk_box_pack_start (GTK_BOX (vbox), hbox2, FALSE, FALSE, 0);
+		gtk_box_pack_start (GTK_BOX (color_vbox), hbox2, FALSE, FALSE, 0);
 		label = gtk_label_new_with_mnemonic (_("Stock _unchanged:"));
 		gtk_misc_set_alignment (GTK_MISC (label), 0.0, 0.5);
 		gtk_box_pack_start (GTK_BOX (hbox2), label, FALSE, FALSE, 0);
@@ -1501,11 +1584,12 @@ static gint updateOutput(gpointer data)
 		gnome_color_picker_set_i8(GNOME_COLOR_PICKER (color), 
 					  ur, ug, ub, 255);
 		gtk_box_pack_start (GTK_BOX (hbox2), color, FALSE, FALSE, 0);
+		gtk_size_group_add_widget (size2, color);
 		g_signal_connect(G_OBJECT(color), "color_set",
 				G_CALLBACK(fgcolor_set_cb), stockdata);
 				
 		hbox2 = gtk_hbox_new (FALSE, 12);
-		gtk_box_pack_start (GTK_BOX (vbox), hbox2, FALSE, FALSE, 0);
+		gtk_box_pack_start (GTK_BOX (color_vbox), hbox2, FALSE, FALSE, 0);
 		label = gtk_label_new_with_mnemonic (_("_Background:"));
 		gtk_misc_set_alignment (GTK_MISC (label), 0.0, 0.5);
 		gtk_box_pack_start (GTK_BOX (hbox2), label, FALSE, FALSE, 0);
@@ -1516,13 +1600,20 @@ static gint updateOutput(gpointer data)
 		gnome_color_picker_set_i8(GNOME_COLOR_PICKER (color), 
 					  ur, ug, ub, 255);
 		gtk_box_pack_start (GTK_BOX (hbox2), color, FALSE, FALSE, 0);
+		gtk_size_group_add_widget (size2, color);
 		g_signal_connect(G_OBJECT(color), "color_set",
 				G_CALLBACK(bgcolor_set_cb), stockdata);
 				
+		gtk_widget_show_all (vbox);
+				
 		g_object_unref (G_OBJECT (size));
+		g_object_unref (G_OBJECT (size2));
 	
 		gtk_widget_show_all(stockdata->pb);
 		
+		gtk_widget_set_sensitive (font_hbox, !stockdata->props.use_default_theme);
+		gtk_widget_set_sensitive (color_vbox, !stockdata->props.use_default_theme);
+		
 		g_signal_connect (G_OBJECT (stockdata->pb), "response",
 				  G_CALLBACK (response_cb), stockdata);
 
@@ -1554,6 +1645,31 @@ static gint updateOutput(gpointer data)
 				      stockdata->props.width,size-4);
     	
     	}
+    	
+    	static void
+    	style_set_cb (GtkWidget *widget, GtkStyle *previous_style, gpointer data)
+    	{
+    		StockData *stockdata = data;
+    		
+    		if (stockdata->props.use_default_theme);
+    			load_fonts (stockdata);
+    	}
+
+	static gboolean 
+	key_press_cb (GtkWidget *widget, GdkEventKey *event, StockData *stockdata)
+	{
+		switch (event->keyval) {	
+		case GDK_u:
+			if (event->state == GDK_CONTROL_MASK)
+				updateOutput(stockdata);
+			return TRUE;
+		default:
+			break;
+		}
+
+		return FALSE;
+
+	}
     
 	static const BonoboUIVerb gtik_applet_menu_verbs [] = {
         	BONOBO_UI_UNSAFE_VERB ("Props", properties_cb),
@@ -1569,6 +1685,7 @@ static gint updateOutput(gpointer data)
 		StockData *stockdata;
 		GtkWidget * vbox;
 		GtkWidget * frame;
+		GtkWidget *event;
 
 		gnome_vfs_init();
 		
@@ -1605,11 +1722,14 @@ static gint updateOutput(gpointer data)
 		stockdata->tooltips = gtk_tooltips_new ();
 		gtk_tooltips_set_tip(stockdata->tooltips, stockdata->leftButton, _("Skip forward"), NULL);
 		gtk_tooltips_set_tip(stockdata->tooltips, stockdata->rightButton, _("Skip backward"), NULL);
-		gtk_tooltips_set_tip(stockdata->tooltips, stockdata->applet, _("Stock Ticker\nGet continuously updated stock quotes"), NULL);
-
-
+		
 		frame = gtk_frame_new(NULL);
 		gtk_frame_set_shadow_type(GTK_FRAME(frame), GTK_SHADOW_IN);
+		
+		event = gtk_event_box_new ();
+		gtk_widget_show (event);
+		gtk_container_add (GTK_CONTAINER(frame), event);
+		gtk_tooltips_set_tip(stockdata->tooltips, event, _("Stock Ticker\nGet continuously updated stock quotes"), NULL);
 
 		access_drawing_area = stockdata->drawing_area = GTK_WIDGET (custom_drawing_area_new());
 		gtk_drawing_area_size(GTK_DRAWING_AREA (stockdata->drawing_area),
@@ -1619,7 +1739,7 @@ static gint updateOutput(gpointer data)
 
 		stockdata->layout = gtk_widget_create_pango_layout (stockdata->drawing_area, "");
 
-		gtk_container_add(GTK_CONTAINER(frame),stockdata->drawing_area);
+		gtk_container_add(GTK_CONTAINER(event),stockdata->drawing_area);
 		
 		gtk_widget_show(frame);
 
@@ -1644,6 +1764,12 @@ static gint updateOutput(gpointer data)
 
 		g_signal_connect (G_OBJECT (applet), "change_size",
 				  G_CALLBACK (applet_change_size), stockdata);
+				  
+		g_signal_connect (G_OBJECT (applet), "style_set",
+					   G_CALLBACK (style_set_cb), stockdata);
+					   
+		g_signal_connect (applet, "key_press_event",
+					  G_CALLBACK (key_press_cb), stockdata);
 
 		gtk_widget_show (GTK_WIDGET (applet));
 		
@@ -1817,15 +1943,18 @@ static gint updateOutput(gpointer data)
 		pango_layout_set_text (stockdata->layout, price, -1);
 		pango_layout_get_pixel_extents (stockdata->layout, NULL, &rect);
 		quote.pricelen = rect.width;
+		quote.priceheight = rect.height;
 		if (change) {
 			quote.change = g_strdup(change);
 			pango_layout_set_text (stockdata->layout, change, -1);
 			pango_layout_get_pixel_extents (stockdata->layout, NULL, &rect);
 			quote.changelen = rect.width;
+			quote.changeheight = rect.height;
 		}
 		else {
 			quote.change = g_strdup("");
 			quote.changelen = 0;
+			quote.changeheight = 0;
 		}
 		
 
