@@ -1,4 +1,4 @@
-/* $Id: gweather-applet.c,v 1.60 2003/06/02 23:30:13 kevinv Exp $ */
+/* $Id: gweather-applet.c,v 1.64 2003/06/23 03:25:39 kevinv Exp $ */
 
 /*
  *  Papadimitriou Spiros <spapadim+@cs.cmu.edu>
@@ -48,11 +48,18 @@ void update_display (GWeatherApplet *applet)
 	GList *list = NULL;
 	GdkPixbuf *pixbuf;
 	gint i = 1;
-	gchar *tmp;
+	gchar *tmp, *degree;
 
+	/* Translators: This is either C for Celius or F for Farenheit */
+	if (applet->gweather_pref.use_metric)
+		degree = "\302\260C";
+	else
+		degree = "\302\260F";
+		
 	if (info->success) {
-		tmp = g_strdup_printf (_("%s\nToday: %s\nCurrent temperature %d"), 
-						  applet->gweather_pref.city, get_conditions (info->wid), info->curtemp);
+		tmp = g_strdup_printf (_("%s\nToday: %s\nCurrent temperature %d%s"), 
+						  applet->gweather_pref.city, get_conditions (info->wid), 
+						  info->curtemp, degree);
 		gtk_tooltips_set_tip (applet->tooltips, applet->events[0], tmp, NULL);
 		g_free (tmp);
 	}
@@ -60,7 +67,7 @@ void update_display (GWeatherApplet *applet)
 		gtk_tooltips_set_tip (applet->tooltips, applet-> events[0], NULL, NULL);
 	pixbuf = get_conditions_pixbuf (info->wid);
 	gtk_image_set_from_pixbuf (GTK_IMAGE (applet->images[0]), pixbuf);
-	tmp = g_strdup_printf ("%d\302\260", info->curtemp);
+	tmp = g_strdup_printf ("%d%s", info->curtemp, degree);
 	gtk_label_set_text (GTK_LABEL (applet->labels[0]), tmp);
 	g_free (tmp);
 
@@ -72,11 +79,11 @@ void update_display (GWeatherApplet *applet)
 			continue;
 		forecast = list->data;	
 		if (info->success)	 {	
-			tmp = g_strdup_printf (_("%s\n%s: %s\nLow %d, High %d"),
+			tmp = g_strdup_printf (_("%s\n%s: %s\nLow %d%s, High %d%s"),
 						  applet->gweather_pref.city,
 						  forecast->day, 
-						  get_conditions (forecast->wid), forecast->low,
-						  forecast->high);
+						  get_conditions (forecast->wid), forecast->low, degree,
+						  forecast->high, degree);
 			gtk_tooltips_set_tip (applet->tooltips, applet->events[i], tmp, NULL);
 			g_free (tmp);
 		}
@@ -84,7 +91,7 @@ void update_display (GWeatherApplet *applet)
 			gtk_tooltips_set_tip (applet->tooltips,applet->events[i], NULL, NULL);
 		pixbuf = get_conditions_pixbuf (forecast->wid);
 		gtk_image_set_from_pixbuf (GTK_IMAGE (applet->images[i]), pixbuf);
-		tmp = g_strdup_printf ("%d/%d\302\260", forecast->high, forecast->low);
+		tmp = g_strdup_printf ("%d/%d%s", forecast->high, forecast->low, degree);
 		gtk_label_set_text (GTK_LABEL (applet->labels[i]), tmp);
 		g_free (tmp);
 		list = g_list_next (list);
@@ -105,6 +112,7 @@ void place_widgets (GWeatherApplet *gw_applet)
     gint i, max_height = 0, max_width = 0;
     gint numrows_or_columns = 1;
     gboolean horiz;
+    gchar*degree;
  
     if (gw_applet->box)
         gtk_widget_destroy (gw_applet->box);
@@ -119,6 +127,11 @@ void place_widgets (GWeatherApplet *gw_applet)
 	 horiz = TRUE;
     }
     
+    if (gw_applet->gweather_pref.use_metric)
+		degree = "\302\260C";
+	else
+		degree = "\302\260F";
+    
     gtk_container_add (GTK_CONTAINER (gw_applet->applet), gw_applet->box);
 
     for (i=0; i<=gw_applet->gweather_info->numforecasts-1; i++) {
@@ -137,9 +150,9 @@ void place_widgets (GWeatherApplet *gw_applet)
 		gw_applet->labels[i] = gtk_label_new (NULL);
 		
 		if (i ==0)
-			tmp = g_strdup_printf ("%d\302\260", 0);
+			tmp = g_strdup_printf ("%d\302\260%s", 0, degree);
 		else
-			tmp = g_strdup_printf ("%d/%d\302\260", 0, 0);
+			tmp = g_strdup_printf ("%d/%d%s", 0, 0, degree);
 		gtk_label_set_text (GTK_LABEL (gw_applet->labels[i]), tmp);
 		gtk_widget_size_request (gw_applet->labels[i], &labelreq);
 		
@@ -160,9 +173,9 @@ void place_widgets (GWeatherApplet *gw_applet)
      	if (horiz && numrows_or_columns == 2)
      		gw_applet->boxes[i] = gtk_vbox_new (FALSE, 0);
      	else if (horiz && numrows_or_columns == 1)
-     		gw_applet->boxes[i] = gtk_hbox_new (FALSE, 0);
+     		gw_applet->boxes[i] = gtk_hbox_new (FALSE, 2);
      	else if (!horiz && numrows_or_columns == 2)
-     		gw_applet->boxes[i] = gtk_hbox_new (FALSE, 0);
+     		gw_applet->boxes[i] = gtk_hbox_new (FALSE, 2);
      	else
      		gw_applet->boxes[i] = gtk_vbox_new (FALSE, 0);
      		
@@ -216,6 +229,39 @@ static gboolean clicked_cb (GtkWidget *widget, GdkEventButton *ev, gpointer data
     return FALSE;
 }
 
+static gboolean 
+key_press_cb (GtkWidget *widget, GdkEventKey *event, GWeatherApplet *gw_applet)
+{
+	switch (event->keyval) {	
+	case GDK_u:
+		if (event->state == GDK_CONTROL_MASK) {
+			gweather_update (gw_applet);
+			return TRUE;
+		}
+		break;
+	case GDK_f:
+		if (event->state == GDK_CONTROL_MASK) {
+			gweather_dialog_open (gw_applet);
+			return TRUE;
+		}
+		break;		
+	case GDK_KP_Enter:
+	case GDK_ISO_Enter:
+	case GDK_3270_Enter:
+	case GDK_Return:
+	case GDK_space:
+	case GDK_KP_Space:
+		gweather_dialog_open(gw_applet);
+		return TRUE;
+		break;
+	default:
+		break;
+	}
+
+	return FALSE;
+
+}
+
 static void about_cb (BonoboUIComponent *uic,
 		      GWeatherApplet    *gw_applet,
 		      const gchar       *verbname)
@@ -298,6 +344,8 @@ void gweather_applet_create (GWeatherApplet *gw_applet)
                        G_CALLBACK (applet_destroy), gw_applet);
     g_signal_connect (G_OBJECT(gw_applet->applet), "button_press_event",
                        G_CALLBACK(clicked_cb), gw_applet);
+    g_signal_connect (G_OBJECT(gw_applet->applet), "key_press_event",
+                       G_CALLBACK(key_press_cb), gw_applet);
                     
     gw_applet->tooltips = gtk_tooltips_new();
 
