@@ -12,14 +12,7 @@
 #include <panel-applet-gconf.h>
 #include <gconf/gconf-client.h>
 
-#define DEFAULT_PATH "/modemlights/"
 
-static GtkWidget *propwindow = NULL;
-static GtkWidget *connect_entry = NULL;
-static GtkWidget *disconnect_entry = NULL;
-static GtkWidget *lockfile_entry = NULL;
-static GtkWidget *device_entry = NULL;
-static GtkWidget *verify_checkbox = NULL;
 
 static void show_extra_info_cb(GtkWidget *widget, gpointer data);
 static void verify_lock_file_cb(GtkWidget *widget, gpointer data);
@@ -56,52 +49,53 @@ static gchar *color_defaults[] = {
 	NULL
 };
 
-void property_load(PanelApplet *applet)
+void property_load(MLData *mldata)
 {
+	PanelApplet *applet = PANEL_APPLET (mldata->applet);
 	GError *error = NULL;
 	gchar *buf;
 	gint i;
 
-	g_free(command_connect);
-	g_free(command_disconnect);
-	g_free(device_name);
+	g_free(mldata->command_connect);
+	g_free(mldata->command_disconnect);
+	g_free(mldata->device_name);
 
-	UPDATE_DELAY = panel_applet_gconf_get_int (applet, "delay", &error);
+	mldata->UPDATE_DELAY = panel_applet_gconf_get_int (applet, "delay", &error);
 	if (error) {
 		g_print ("%s \n", error->message);
 		g_error_free (error);
 		error = NULL;
 	}
-	UPDATE_DELAY = MAX (UPDATE_DELAY, 1);
+	mldata->UPDATE_DELAY = MAX (mldata->UPDATE_DELAY, 1);
 	
 	buf = panel_applet_gconf_get_string(applet, "lockfile", NULL);
 	if (buf && strlen(buf) > 0)
 		{
-		g_free(lock_file);
-		lock_file = g_strdup(buf);
+		g_free(mldata->lock_file);
+		mldata->lock_file = g_strdup(buf);
 		}
 	g_free(buf);
 
-	command_connect    = panel_applet_gconf_get_string(applet, "connect", NULL);
-	if (!command_connect)
-		command_connect = g_strdup ("pppon");
-	command_disconnect = panel_applet_gconf_get_string(applet, "disconnect", NULL);
-	if (!command_disconnect)
-		command_disconnect = g_strdup ("pppoff");
-	ask_for_confirmation = panel_applet_gconf_get_int(applet, "confirmation", NULL);
-	device_name          = panel_applet_gconf_get_string(applet, "device", NULL);
-	if (!device_name)
-		device_name = g_strdup ("ppp0");
-	use_ISDN	   = panel_applet_gconf_get_int(applet, "isdn", NULL);
-       	verify_lock_file   = panel_applet_gconf_get_int(applet, "verify_lock", NULL);
-	show_extra_info    = panel_applet_gconf_get_int(applet, "extra_info", NULL);
-	status_wait_blink  = panel_applet_gconf_get_int(applet, "wait_blink", NULL);
+	mldata->command_connect    = panel_applet_gconf_get_string(applet, "connect", NULL);
+	if (!mldata->command_connect)
+		mldata->command_connect = g_strdup ("pppon");
+	mldata->command_disconnect = panel_applet_gconf_get_string(applet, "disconnect", NULL);
+	if (!mldata->command_disconnect)
+		mldata->command_disconnect = g_strdup ("pppoff");
+	mldata->ask_for_confirmation = panel_applet_gconf_get_int(applet, "confirmation", NULL);
+	mldata->device_name = panel_applet_gconf_get_string(applet, "device", NULL);
+	if (!mldata->device_name)
+		mldata->device_name = g_strdup ("ppp0");
+	mldata->use_ISDN = panel_applet_gconf_get_int(applet, "isdn", NULL);
+       	mldata->verify_lock_file  = panel_applet_gconf_get_int(applet, "verify_lock", NULL);
+	mldata->show_extra_info  = panel_applet_gconf_get_int(applet, "extra_info", NULL);
+	mldata->status_wait_blink  = panel_applet_gconf_get_int(applet, "wait_blink", NULL);
 	
 	for (i = 0; i < COLOR_COUNT; i++)
 		{
-		g_free(display_color_text[i]);
+		g_free(mldata->display_color_text[i]);
 		
-		display_color_text[i] = panel_applet_gconf_get_string(applet, 
+		mldata->display_color_text[i] = panel_applet_gconf_get_string(applet, 
 							              color_rc_names[i], 
 							              NULL);
 		
@@ -112,99 +106,109 @@ void property_load(PanelApplet *applet)
 
 static void connect_changed_cb(GtkEntry *entry, GdkEventFocus *event, gpointer data)
 {
-	PanelApplet *applet = data;
+	MLData *mldata = data;
+	PanelApplet *applet = PANEL_APPLET (mldata->applet);
 	
-	if (command_connect) g_free(command_connect);
-	command_connect = gtk_editable_get_chars(GTK_EDITABLE(entry), 0, -1);
-	panel_applet_gconf_set_string (applet, "connect", command_connect, NULL);
+	if (mldata->command_connect) g_free(mldata->command_connect);
+	mldata->command_connect = gtk_editable_get_chars(GTK_EDITABLE(entry), 0, -1);
+	panel_applet_gconf_set_string (applet, "connect", mldata->command_connect, NULL);
 }
 
 static void disconnect_changed_cb(GtkEntry *entry, GdkEventFocus *event, gpointer data)
 {
-	PanelApplet *applet = data;
+	MLData *mldata = data;
+	PanelApplet *applet = PANEL_APPLET (mldata->applet);
 	
-	if (command_disconnect) g_free(command_disconnect);
-	command_disconnect = gtk_editable_get_chars(GTK_EDITABLE(entry), 0, -1);
-	panel_applet_gconf_set_string (applet, "disconnect", command_disconnect, NULL);
+	if (mldata->command_disconnect) g_free(mldata->command_disconnect);
+	mldata->command_disconnect = gtk_editable_get_chars(GTK_EDITABLE(entry), 0, -1);
+	panel_applet_gconf_set_string (applet, "disconnect", mldata->command_disconnect, NULL);
 }
 
 static void lockfile_changed_cb(GtkEntry *entry, GdkEventFocus *event, gpointer data)
 {
-	PanelApplet *applet = data;
+	MLData *mldata = data;
+	PanelApplet *applet = PANEL_APPLET (mldata->applet);
 	
-	if (lock_file) g_free(lock_file);
-	lock_file = gtk_editable_get_chars(GTK_EDITABLE(entry), 0, -1);
-	panel_applet_gconf_set_string (applet, "lockfile", lock_file, NULL);
+	if (mldata->lock_file) g_free(mldata->lock_file);
+	mldata->lock_file = gtk_editable_get_chars(GTK_EDITABLE(entry), 0, -1);
+	panel_applet_gconf_set_string (applet, "lockfile", mldata->lock_file, NULL);
 }
 
 static void device_changed_cb(GtkEntry *entry, GdkEventFocus *event, gpointer data)
 {
-	PanelApplet *applet = data;
+	MLData *mldata = data;
+	PanelApplet *applet = PANEL_APPLET (mldata->applet);
 	
-	if (device_name) g_free(device_name);
-	device_name = gtk_editable_get_chars(GTK_EDITABLE(entry), 0, -1);
-	panel_applet_gconf_set_string (applet, "device", device_name, NULL);
+	if (mldata->device_name) g_free(mldata->device_name);
+	mldata->device_name = gtk_editable_get_chars(GTK_EDITABLE(entry), 0, -1);
+	panel_applet_gconf_set_string (applet, "device", mldata->device_name, NULL);
 }
 
 static void show_extra_info_cb(GtkWidget *widget, gpointer data)
 {
-	PanelApplet *applet = data;
+	MLData *mldata = data;
+	PanelApplet *applet = PANEL_APPLET (mldata->applet);
 	
 	gint tmp = GTK_TOGGLE_BUTTON (widget)->active;
-	if (tmp != show_extra_info)
+	if (tmp != mldata->show_extra_info)
 		{
-		show_extra_info = tmp;
+		mldata->show_extra_info = tmp;
 		/* change display */
-		reset_orientation();
-		panel_applet_gconf_set_int (applet, "extra_info", show_extra_info, NULL);
+		reset_orientation(mldata);
+		panel_applet_gconf_set_int (applet, "extra_info", mldata->show_extra_info, NULL);
 		}
 }
 
 static void verify_lock_file_cb(GtkWidget *widget, gpointer data)
 {
-	PanelApplet *applet = data;
+	MLData *mldata = data;
+	PanelApplet *applet = PANEL_APPLET (mldata->applet);
 	
-	verify_lock_file = GTK_TOGGLE_BUTTON (widget)->active;
-	panel_applet_gconf_set_int (applet, "verify_lock", verify_lock_file, NULL);
+	mldata->verify_lock_file = GTK_TOGGLE_BUTTON (widget)->active;
+	panel_applet_gconf_set_int (applet, "verify_lock", mldata->verify_lock_file, NULL);
 
 }
 
 static void update_delay_cb(GtkWidget *widget, GdkEventFocus *event, gpointer data)
 {
-	PanelApplet *applet = data;
+	MLData *mldata = data;
+	PanelApplet *applet = PANEL_APPLET (mldata->applet);
 	gchar *key;
 	
-        UPDATE_DELAY = gtk_spin_button_get_value_as_int(GTK_SPIN_BUTTON(widget));
-        start_callback_update();
-        panel_applet_gconf_set_int (applet, "delay", UPDATE_DELAY, NULL);
+        mldata->UPDATE_DELAY = gtk_spin_button_get_value_as_int(GTK_SPIN_BUTTON(widget));
+        start_callback_update(mldata);
+        panel_applet_gconf_set_int (applet, "delay", mldata->UPDATE_DELAY, NULL);
 }
 
 static void confirm_checkbox_cb(GtkWidget *widget, gpointer data)
 {
-	PanelApplet *applet = data;
+	MLData *mldata = data;
+	PanelApplet *applet = PANEL_APPLET (mldata->applet);
 	
-	ask_for_confirmation = GTK_TOGGLE_BUTTON (widget)->active;
-	panel_applet_gconf_set_int (applet, "confirmation", ask_for_confirmation, NULL);
+	mldata->ask_for_confirmation = GTK_TOGGLE_BUTTON (widget)->active;
+	panel_applet_gconf_set_int (applet, "confirmation", mldata->ask_for_confirmation, NULL);
 }
 
 static void wait_blink_cb(GtkWidget *widget, gpointer data)
 {
-	PanelApplet *applet = data;
+	MLData *mldata = data;
+	PanelApplet *applet = PANEL_APPLET (mldata->applet);
 	
-	status_wait_blink = GTK_TOGGLE_BUTTON (widget)->active;
-	panel_applet_gconf_set_int (applet, "wait_blink", status_wait_blink, NULL);
+	mldata->status_wait_blink = GTK_TOGGLE_BUTTON (widget)->active;
+	panel_applet_gconf_set_int (applet, "wait_blink", mldata->status_wait_blink, NULL);
 }
 
 static void isdn_checkbox_cb(GtkWidget *widget, gpointer data)
 {
-	PanelApplet *applet = data;
+	MLData *mldata = data;
+	PanelApplet *applet = PANEL_APPLET (mldata->applet);
 	
-	use_ISDN = GTK_TOGGLE_BUTTON (widget)->active;
+	mldata->use_ISDN = GTK_TOGGLE_BUTTON (widget)->active;
 
-	gtk_widget_set_sensitive(lockfile_entry, !use_ISDN);
-	gtk_widget_set_sensitive(device_entry, !use_ISDN);
-	gtk_widget_set_sensitive(verify_checkbox, !use_ISDN);
-	panel_applet_gconf_set_int (applet, "isdn", use_ISDN, NULL);
+	gtk_widget_set_sensitive(mldata->lockfile_entry, !mldata->use_ISDN);
+	gtk_widget_set_sensitive(mldata->device_entry, !mldata->use_ISDN);
+	gtk_widget_set_sensitive(mldata->verify_checkbox, !mldata->use_ISDN);
+	panel_applet_gconf_set_int (applet, "isdn", mldata->use_ISDN, NULL);
 }
 
 static void set_default_cb(GtkWidget *widget, gpointer data)
@@ -214,25 +218,28 @@ static void set_default_cb(GtkWidget *widget, gpointer data)
 
 static void box_color_cb(GnomeColorPicker *cp, guint nopr, guint nopg, guint nopb, guint nopa, gpointer data)
 {
+	MLData *mldata;
 	PanelApplet *applet;
 	ColorType color	= (ColorType)GPOINTER_TO_INT(data);
 	guint8 r, g, b, a;
 
 	gnome_color_picker_get_i8 (GNOME_COLOR_PICKER(cp), &r, &g, &b, &a);
-
-	g_free(display_color_text[color]);
-	display_color_text[color] = g_strdup_printf("#%06X", (r << 16) + (g << 8) + b);
+	mldata = g_object_get_data (G_OBJECT (cp), "mldata");
 	
-	reset_colors ();
+	g_free(mldata->display_color_text[color]);
+	mldata->display_color_text[color] = g_strdup_printf("#%06X", (r << 16) + (g << 8) + b);
 	
-	applet = g_object_get_data (G_OBJECT (cp), "applet");
+	reset_colors (mldata);
+	
+	applet = PANEL_APPLET (mldata->applet);
 	panel_applet_gconf_set_string (applet, color_rc_names[color], 
-				       display_color_text[color], NULL);
+				       mldata->display_color_text[color], NULL);
 }
 
-static GtkWidget *box_add_color(PanelApplet *applet, GtkWidget *box, 
+static GtkWidget *box_add_color(MLData *mldata, GtkWidget *box, 
 				const gchar *text, ColorType color)
 {
+	PanelApplet *applet = PANEL_APPLET (mldata->applet);
 	GtkWidget *hbox;
 	GtkWidget *label;
 	GtkWidget *color_sel;
@@ -242,9 +249,9 @@ static GtkWidget *box_add_color(PanelApplet *applet, GtkWidget *box,
 	gtk_box_pack_start (GTK_BOX(box), hbox, FALSE, FALSE, 0);
 	gtk_widget_show (hbox);
 
-	if (display_color_text[color] != NULL)
+	if (mldata->display_color_text[color] != NULL)
 		{
-		gdk_color_parse(display_color_text[color], &c);
+		gdk_color_parse(mldata->display_color_text[color], &c);
 		}
 	else
 		{
@@ -262,7 +269,7 @@ static GtkWidget *box_add_color(PanelApplet *applet, GtkWidget *box,
 	gtk_label_set_mnemonic_widget (GTK_LABEL (label), color_sel);
 	g_signal_connect(G_OBJECT(color_sel), "color_set", 
 			 G_CALLBACK (box_color_cb), GINT_TO_POINTER((gint)color));
-	g_object_set_data (G_OBJECT (color_sel), "applet", applet);
+	g_object_set_data (G_OBJECT (color_sel), "mldata", mldata);
 	gtk_box_pack_start(GTK_BOX(hbox), color_sel, FALSE, FALSE, 0);
 	gtk_widget_show(color_sel);
 
@@ -332,19 +339,21 @@ phelp_cb (GtkDialog *dialog)
 static void
 property_response_cb (GtkDialog *dialog, gint id, gpointer data)
 {
+	MLData *mldata = data;
 	if (id == GTK_RESPONSE_HELP) {
 		phelp_cb (dialog);
 		return;
 	}
 	
 	gtk_widget_destroy (GTK_WIDGET (dialog));
-	propwindow = NULL;
+	mldata->propwindow = NULL;
 }
 
 void property_show (BonoboUIComponent *uic,
-		    PanelApplet       *applet,
+		    MLData       *mldata,
 		    const gchar       *verbname)
 {
+	PanelApplet *applet = PANEL_APPLET (mldata->applet);
 	GtkWidget *frame;
 	GtkWidget *hbox, *hbox2, *hbox3;
 	GtkWidget *notebook;
@@ -355,28 +364,29 @@ void property_show (BonoboUIComponent *uic,
 	GtkWidget *checkbox;
 	GtkSizeGroup *size_group;
 
-	if (propwindow) {
-		gtk_window_set_screen (GTK_WINDOW (propwindow),
+	if (mldata->propwindow) {
+		gtk_window_set_screen (GTK_WINDOW (mldata->propwindow),
 				       gtk_widget_get_screen (GTK_WIDGET (applet)));
-		gtk_window_present (GTK_WINDOW (propwindow));
+		gtk_window_present (GTK_WINDOW (mldata->propwindow));
 		return;
 	}
 
-        propwindow = gtk_dialog_new_with_buttons (_("Modem Lights Preferences"), NULL,
+        mldata->propwindow = gtk_dialog_new_with_buttons (_("Modem Lights Preferences"), NULL,
 						  GTK_DIALOG_DESTROY_WITH_PARENT,
 						  GTK_STOCK_HELP, GTK_RESPONSE_HELP,
 						  GTK_STOCK_CLOSE, GTK_RESPONSE_CLOSE,
 						  NULL);
-	gtk_window_set_screen (GTK_WINDOW (propwindow),
+	gtk_window_set_screen (GTK_WINDOW (mldata->propwindow),
 			       gtk_widget_get_screen (GTK_WIDGET (applet)));
-	gtk_dialog_set_default_response (GTK_DIALOG (propwindow), GTK_RESPONSE_CLOSE);
-  	gtk_dialog_set_has_separator (GTK_DIALOG (propwindow), FALSE);
-	gtk_window_set_resizable (GTK_WINDOW (propwindow), FALSE);
+	gtk_dialog_set_default_response (GTK_DIALOG (mldata->propwindow), GTK_RESPONSE_CLOSE);
+  	gtk_dialog_set_has_separator (GTK_DIALOG (mldata->propwindow), FALSE);
+	gtk_container_set_border_width (GTK_CONTAINER (mldata->propwindow), 5);
+	gtk_window_set_resizable (GTK_WINDOW (mldata->propwindow), FALSE);
 
 	notebook = gtk_notebook_new ();
 	vbox = gtk_vbox_new (FALSE, 6);
-	gtk_container_set_border_width (GTK_CONTAINER (notebook), 12);
-	gtk_box_pack_start (GTK_BOX (GTK_DIALOG (propwindow)->vbox), notebook,
+	gtk_container_set_border_width (GTK_CONTAINER (notebook), 5);
+	gtk_box_pack_start (GTK_BOX (GTK_DIALOG (mldata->propwindow)->vbox), notebook,
 			    TRUE, TRUE, 0);
 	
 	vbox = gtk_vbox_new (FALSE, 18);
@@ -393,31 +403,35 @@ void property_show (BonoboUIComponent *uic,
         gtk_box_pack_start (GTK_BOX (hbox), label, FALSE, FALSE, 0);
 	gtk_widget_show (label);
 
-	delay_adj = gtk_adjustment_new( UPDATE_DELAY, 1.0, 20.0, 1, 1, 1 );
+	hbox2 = gtk_hbox_new (FALSE, 6);
+	gtk_box_pack_start (GTK_BOX (hbox), hbox2, FALSE, FALSE, 0);
+	gtk_widget_show (hbox2);
+
+	delay_adj = gtk_adjustment_new( mldata->UPDATE_DELAY, 1.0, 20.0, 1, 1, 1 );
         delay_w  = gtk_spin_button_new( GTK_ADJUSTMENT(delay_adj), 1, 0 );
 	gtk_label_set_mnemonic_widget (GTK_LABEL (label), delay_w);
-	gtk_box_pack_start (GTK_BOX (hbox), delay_w, FALSE, FALSE, 0);
+	gtk_box_pack_start (GTK_BOX (hbox2), delay_w, FALSE, FALSE, 0);
 	g_signal_connect (G_OBJECT (delay_w), "focus-out-event",
-			  G_CALLBACK (update_delay_cb), applet);
+			  G_CALLBACK (update_delay_cb), mldata);
 	gtk_spin_button_set_update_policy (GTK_SPIN_BUTTON (delay_w),GTK_UPDATE_ALWAYS );
 	gtk_widget_show (delay_w);
 
 	label = gtk_label_new_with_mnemonic (_("seconds"));
-        gtk_box_pack_start (GTK_BOX (hbox), label, FALSE, FALSE, 0);
+        gtk_box_pack_start (GTK_BOX (hbox2), label, FALSE, FALSE, 0);
 	gtk_widget_show (label);
 
 	/* extra info checkbox */
 	checkbox = gtk_check_button_new_with_mnemonic (_("Sho_w connect time and throughput"));
-	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (checkbox), show_extra_info);
+	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (checkbox), mldata->show_extra_info);
 	g_signal_connect (G_OBJECT (checkbox), "toggled",
-			 G_CALLBACK (show_extra_info_cb), applet);
+			 G_CALLBACK (show_extra_info_cb), mldata);
 	gtk_box_pack_start (GTK_BOX (frame), checkbox, FALSE, FALSE, 0);
 	gtk_widget_show (checkbox);
 
 	checkbox = gtk_check_button_new_with_mnemonic (_("B_link connection status when connecting"));
-	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (checkbox), status_wait_blink);
+	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (checkbox), mldata->status_wait_blink);
 	g_signal_connect (G_OBJECT (checkbox), "toggled",
-			 G_CALLBACK (wait_blink_cb), applet);
+			 G_CALLBACK (wait_blink_cb), mldata);
 	gtk_box_pack_start (GTK_BOX (frame), checkbox, FALSE, FALSE, 0);
 	gtk_widget_show (checkbox);
 
@@ -436,13 +450,13 @@ void property_show (BonoboUIComponent *uic,
         gtk_box_pack_start(GTK_BOX(hbox), label, FALSE, FALSE, 0);
 	gtk_widget_show(label);
 
-	connect_entry = gtk_entry_new_with_max_length(255);
-	gtk_label_set_mnemonic_widget (GTK_LABEL (label), connect_entry);
-	gtk_entry_set_text(GTK_ENTRY(connect_entry), command_connect);
-	g_signal_connect (G_OBJECT (connect_entry), "focus_out_event",
-			  G_CALLBACK (connect_changed_cb), applet);			  
-        gtk_box_pack_start(GTK_BOX(hbox), connect_entry , TRUE, TRUE, 0);
-	gtk_widget_show(connect_entry);
+	mldata->connect_entry = gtk_entry_new_with_max_length(255);
+	gtk_label_set_mnemonic_widget (GTK_LABEL (label), mldata->connect_entry);
+	gtk_entry_set_text(GTK_ENTRY(mldata->connect_entry), mldata->command_connect);
+	g_signal_connect (G_OBJECT (mldata->connect_entry), "focus_out_event",
+			  G_CALLBACK (connect_changed_cb), mldata);			  
+        gtk_box_pack_start(GTK_BOX(hbox), mldata->connect_entry , TRUE, TRUE, 0);
+	gtk_widget_show(mldata->connect_entry);
 
 	/* disconnect entry */
 	hbox = gtk_hbox_new(FALSE, 12);
@@ -455,19 +469,19 @@ void property_show (BonoboUIComponent *uic,
 	gtk_box_pack_start (GTK_BOX (hbox), label, FALSE, FALSE, 0);
 	gtk_widget_show(label);
 
-	disconnect_entry = gtk_entry_new_with_max_length(255);
-	gtk_label_set_mnemonic_widget (GTK_LABEL (label), disconnect_entry);
-	gtk_entry_set_text(GTK_ENTRY(disconnect_entry), command_disconnect);
-	g_signal_connect (G_OBJECT (disconnect_entry), "focus_out_event",
-			  G_CALLBACK (disconnect_changed_cb), applet);
-        gtk_box_pack_start(GTK_BOX(hbox), disconnect_entry, TRUE, TRUE, 0);
-	gtk_widget_show(disconnect_entry);
+	mldata->disconnect_entry = gtk_entry_new_with_max_length(255);
+	gtk_label_set_mnemonic_widget (GTK_LABEL (label), mldata->disconnect_entry);
+	gtk_entry_set_text(GTK_ENTRY(mldata->disconnect_entry), mldata->command_disconnect);
+	g_signal_connect (G_OBJECT (mldata->disconnect_entry), "focus_out_event",
+			  G_CALLBACK (disconnect_changed_cb), mldata);
+        gtk_box_pack_start(GTK_BOX(hbox), mldata->disconnect_entry, TRUE, TRUE, 0);
+	gtk_widget_show(mldata->disconnect_entry);
 
 	/* confirmation checkbox */
 	checkbox = gtk_check_button_new_with_mnemonic(_("Con_firm connection"));
-	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (checkbox), ask_for_confirmation);
+	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (checkbox), mldata->ask_for_confirmation);
 	g_signal_connect (G_OBJECT (checkbox), "toggled",
-			  G_CALLBACK (confirm_checkbox_cb), applet);
+			  G_CALLBACK (confirm_checkbox_cb), mldata);
 	gtk_box_pack_start (GTK_BOX (frame), checkbox, FALSE, FALSE, 0);
 	gtk_widget_show(checkbox);
 
@@ -486,9 +500,9 @@ void property_show (BonoboUIComponent *uic,
 	hbox2 = gtk_hbox_new (FALSE, 24);
 	gtk_box_pack_start (GTK_BOX (hbox), hbox2, FALSE, FALSE, 0);
 
-	hbox3 = box_add_color (applet, hbox2, _("_Foreground:"), COLOR_RX);
+	hbox3 = box_add_color (mldata, hbox2, _("_Foreground:"), COLOR_RX);
 	gtk_size_group_add_widget (size_group, hbox3);
-	hbox3 = box_add_color (applet, hbox2, _("_Background:"), COLOR_RX_BG);
+	hbox3 = box_add_color (mldata, hbox2, _("_Background:"), COLOR_RX_BG);
 	gtk_size_group_add_widget (size_group, hbox3);
 	
 	hbox = color_frame_new(vbox, _("Send Data"));
@@ -496,9 +510,9 @@ void property_show (BonoboUIComponent *uic,
 	hbox2 = gtk_hbox_new (FALSE, 24);
 	gtk_box_pack_start (GTK_BOX (hbox), hbox2, FALSE, FALSE, 0);
 	
-	hbox3 = box_add_color (applet, hbox2, _("Foregroun_d:"), COLOR_TX);
+	hbox3 = box_add_color (mldata, hbox2, _("Foregroun_d:"), COLOR_TX);
 	gtk_size_group_add_widget (size_group, hbox3);
-	hbox3 = box_add_color (applet, hbox2, _("Backg_round:"), COLOR_TX_BG);
+	hbox3 = box_add_color (mldata, hbox2, _("Backg_round:"), COLOR_TX_BG);
 	gtk_size_group_add_widget (size_group, hbox3);
 	
 	hbox = color_frame_new (vbox, _("Connection Status"));
@@ -509,12 +523,12 @@ void property_show (BonoboUIComponent *uic,
 	hbox2 = gtk_hbox_new (FALSE, 24);
 	gtk_box_pack_start (GTK_BOX (vbox2), hbox2, FALSE, FALSE, 0);
 	
-	hbox3 = box_add_color (applet, hbox2, _("Co_nnected:"), COLOR_STATUS_OK);
+	hbox3 = box_add_color (mldata, hbox2, _("Co_nnected:"), COLOR_STATUS_OK);
 	gtk_size_group_add_widget (size_group, hbox3);
-	hbox3 = box_add_color (applet, hbox2, _("Disconnec_ted:"), COLOR_STATUS_BG);
+	hbox3 = box_add_color (mldata, hbox2, _("Disconnec_ted:"), COLOR_STATUS_BG);
 	gtk_size_group_add_widget (size_group, hbox3);
 		
-	hbox3 = box_add_color (applet, vbox2, _("C_onnecting:"), COLOR_STATUS_WAIT);
+	hbox3 = box_add_color (mldata, vbox2, _("C_onnecting:"), COLOR_STATUS_WAIT);
 	gtk_size_group_add_widget (size_group, hbox3);
 	
 	hbox = color_frame_new (vbox, _("Text"));
@@ -525,11 +539,11 @@ void property_show (BonoboUIComponent *uic,
 	hbox2 = gtk_hbox_new (FALSE, 24);
 	gtk_box_pack_start (GTK_BOX (vbox2), hbox2, FALSE, FALSE, 0);
 	
-	hbox3 = box_add_color (applet, hbox2, _("For_eground:"), COLOR_TEXT_FG);
+	hbox3 = box_add_color (mldata, hbox2, _("For_eground:"), COLOR_TEXT_FG);
 	gtk_size_group_add_widget (size_group, hbox3);
-	hbox3 = box_add_color (applet, hbox2, _("Bac_kground:"), COLOR_TEXT_BG);
+	hbox3 = box_add_color (mldata, hbox2, _("Bac_kground:"), COLOR_TEXT_BG);
 	gtk_size_group_add_widget (size_group, hbox3);
-	hbox3 = box_add_color (applet, vbox2, _("O_utline"), COLOR_TEXT_MID);
+	hbox3 = box_add_color (mldata, vbox2, _("O_utline"), COLOR_TEXT_MID);
         gtk_size_group_add_widget (size_group, hbox3);
 
 	label = gtk_label_new (_("Colors"));
@@ -556,13 +570,13 @@ void property_show (BonoboUIComponent *uic,
         gtk_box_pack_start (GTK_BOX (hbox), label, FALSE, FALSE, 0);
 	gtk_widget_show (label);
 
-	device_entry = gtk_entry_new_with_max_length (16);
-	gtk_label_set_mnemonic_widget (GTK_LABEL (label), device_entry);
-	gtk_entry_set_text (GTK_ENTRY (device_entry), device_name);
-	g_signal_connect (G_OBJECT (device_entry), "focus_out_event",
-			  G_CALLBACK (device_changed_cb), applet);
-        gtk_box_pack_start (GTK_BOX (hbox), device_entry, TRUE, TRUE, 0);
-	gtk_widget_show (device_entry);
+	mldata->device_entry = gtk_entry_new_with_max_length (16);
+	gtk_label_set_mnemonic_widget (GTK_LABEL (label), mldata->device_entry);
+	gtk_entry_set_text (GTK_ENTRY (mldata->device_entry), mldata->device_name);
+	g_signal_connect (G_OBJECT (mldata->device_entry), "focus_out_event",
+			  G_CALLBACK (device_changed_cb), mldata);
+        gtk_box_pack_start (GTK_BOX (hbox), mldata->device_entry, TRUE, TRUE, 0);
+	gtk_widget_show (mldata->device_entry);
 	
 	/* lock file entry */
 	hbox = gtk_hbox_new(FALSE, 12);
@@ -575,54 +589,42 @@ void property_show (BonoboUIComponent *uic,
         gtk_box_pack_start (GTK_BOX (hbox), label, FALSE, FALSE, 0);
 	gtk_widget_show (label);
 
-	lockfile_entry = gtk_entry_new_with_max_length(255);
-	gtk_label_set_mnemonic_widget (GTK_LABEL (label), lockfile_entry);
-	gtk_entry_set_text(GTK_ENTRY(lockfile_entry), lock_file);
-	g_signal_connect (G_OBJECT (lockfile_entry), "focus_out_event",
-			  G_CALLBACK (lockfile_changed_cb), applet);
-        gtk_box_pack_start(GTK_BOX(hbox), lockfile_entry, TRUE, TRUE, 0);
-	gtk_widget_show(lockfile_entry);
+	mldata->lockfile_entry = gtk_entry_new_with_max_length(255);
+	gtk_label_set_mnemonic_widget (GTK_LABEL (label), mldata->lockfile_entry);
+	gtk_entry_set_text(GTK_ENTRY(mldata->lockfile_entry), mldata->lock_file);
+	g_signal_connect (G_OBJECT (mldata->lockfile_entry), "focus_out_event",
+			  G_CALLBACK (lockfile_changed_cb), mldata);
+        gtk_box_pack_start(GTK_BOX(hbox), mldata->lockfile_entry, TRUE, TRUE, 0);
+	gtk_widget_show(mldata->lockfile_entry);
 
-	verify_checkbox = gtk_check_button_new_with_mnemonic(_("_Verify owner of lock file"));
-	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (verify_checkbox), verify_lock_file);
-	g_signal_connect(G_OBJECT(verify_checkbox), "toggled",
-			 G_CALLBACK(verify_lock_file_cb), applet);
-	gtk_box_pack_start (GTK_BOX (frame), verify_checkbox, FALSE, FALSE, 0);
-	gtk_widget_show(verify_checkbox);
+	mldata->verify_checkbox = gtk_check_button_new_with_mnemonic(_("_Verify owner of lock file"));
+	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (mldata->verify_checkbox), mldata->verify_lock_file);
+	g_signal_connect(G_OBJECT(mldata->verify_checkbox), "toggled",
+			 G_CALLBACK(verify_lock_file_cb), mldata);
+	gtk_box_pack_start (GTK_BOX (frame), mldata->verify_checkbox, FALSE, FALSE, 0);
+	gtk_widget_show(mldata->verify_checkbox);
 
 	/* ISDN checkbox */
 	checkbox = gtk_check_button_new_with_mnemonic(_("U_se ISDN"));
-	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (checkbox), use_ISDN);
+	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (checkbox), mldata->use_ISDN);
 	g_signal_connect(G_OBJECT(checkbox), "toggled",
-			   G_CALLBACK(isdn_checkbox_cb), applet);
+			   G_CALLBACK(isdn_checkbox_cb), mldata);
 	gtk_box_pack_start (GTK_BOX (frame), checkbox, FALSE, FALSE, 0);
 	gtk_widget_show(checkbox);
 
-	if (use_ISDN)
+	if (mldata->use_ISDN)
 		{
-		gtk_widget_set_sensitive(lockfile_entry, FALSE);
-		gtk_widget_set_sensitive(device_entry, FALSE);
-		gtk_widget_set_sensitive(verify_checkbox, FALSE);
+		gtk_widget_set_sensitive(mldata->lockfile_entry, FALSE);
+		gtk_widget_set_sensitive(mldata->device_entry, FALSE);
+		gtk_widget_set_sensitive(mldata->verify_checkbox, FALSE);
 		}
-#ifdef SHOULD_THIS_BE_HERE
-	/* defaults save button */
-	
-	hbox = gtk_hbox_new (FALSE, 12);
-	gtk_box_pack_end (GTK_BOX (frame), hbox, FALSE, FALSE, 0);
-	gtk_widget_show(hbox);
 
-	button = gtk_button_new_with_label(_("Set options as default"));
-	/*gtk_signal_connect(GTK_OBJECT(button), "clicked",
-			   GTK_SIGNAL_FUNC(set_default_cb), NULL);*/
-	gtk_box_pack_end(GTK_BOX(hbox), button, FALSE, FALSE, 0);
-	gtk_widget_show(button);
-#endif
         label = gtk_label_new(_("Advanced"));
         gtk_widget_show(vbox);
         gtk_notebook_append_page( GTK_NOTEBOOK(notebook), vbox, label);
 
-	g_signal_connect (G_OBJECT (propwindow), "response",
-			  G_CALLBACK (property_response_cb), NULL);
+	g_signal_connect (G_OBJECT (mldata->propwindow), "response",
+			  G_CALLBACK (property_response_cb), mldata);
 
-        gtk_widget_show_all(propwindow);
+        gtk_widget_show_all(mldata->propwindow);
 } 
