@@ -51,6 +51,8 @@ static gboolean stickynotes_applet_factory(PanelApplet *panel_applet, const gcha
 	if (!strcmp(iid, "OAFIID:GNOME_StickyNotesApplet")) {
 		if (!stickynotes)
 			stickynotes_applet_init();
+			
+		panel_applet_set_flags (panel_applet, PANEL_APPLET_EXPAND_MINOR);
 
 		/* Add applet to linked list of all applets */
 		stickynotes->applets = g_list_append(stickynotes->applets, stickynotes_applet_new(panel_applet));
@@ -197,7 +199,10 @@ StickyNotesApplet * stickynotes_applet_new(PanelApplet *panel_applet)
 	applet->prelighted = FALSE;
 	applet->pressed = FALSE;
 
-	/* Create the applet */
+	/* Expand the applet for Fitts' law complience. */
+	panel_applet_set_flags(panel_applet, PANEL_APPLET_EXPAND_MINOR);
+
+	/* Add the applet icon */
 	gtk_container_add(GTK_CONTAINER(panel_applet), applet->w_image);
 	stickynotes_applet_update_icon(applet);
 
@@ -207,6 +212,8 @@ StickyNotesApplet * stickynotes_applet_new(PanelApplet *panel_applet)
 	bonobo_ui_component_add_listener(panel_applet_get_popup_component(panel_applet), "show", (BonoboUIListenerFn) menu_toggle_show_cb, applet);
 	bonobo_ui_component_add_listener(panel_applet_get_popup_component(panel_applet), "lock", (BonoboUIListenerFn) menu_toggle_lock_cb, applet);
 
+	gtk_widget_add_events(applet->w_applet, GDK_KEY_PRESS_MASK | GDK_KEY_RELEASE_MASK); /* FIXME : Doesn't work */
+
 	/* Connect all signals for applet management */
 	g_signal_connect(G_OBJECT(applet->w_applet), "button-press-event", G_CALLBACK(applet_button_cb), applet);
 	g_signal_connect(G_OBJECT(applet->w_applet), "button-release-event", G_CALLBACK(applet_button_cb), applet);
@@ -288,14 +295,24 @@ void stickynotes_applet_update_menus()
 {
 	gboolean visible = gconf_client_get_bool(stickynotes->gconf, GCONF_PATH "/settings/visible", NULL);
 	gboolean locked = gconf_client_get_bool(stickynotes->gconf, GCONF_PATH "/settings/locked", NULL);
+	gboolean inconsistent = FALSE;
 
 	gint i;
+
+	for (i = 0; i < g_list_length(stickynotes->notes) && !inconsistent; i++) {
+		StickyNote *note = g_list_nth_data(stickynotes->notes, i);
+
+		if (note->locked != locked)
+			inconsistent = TRUE;
+	}
+
 	for (i = 0; i < g_list_length(stickynotes->applets); i++) {
 		StickyNotesApplet *applet = g_list_nth_data(stickynotes->applets, i);
 		BonoboUIComponent *popup = panel_applet_get_popup_component(PANEL_APPLET(applet->w_applet));
 		
 		bonobo_ui_component_set_prop(popup, "/commands/show", "state", visible ? "1" : "0", NULL);
 		bonobo_ui_component_set_prop(popup, "/commands/lock", "state", locked ? "1" : "0", NULL);
+		bonobo_ui_component_set_prop(popup, "/commands/lock", "inconsistent", inconsistent ? "1" : "0", NULL);
 	}
 }
 
